<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Aleksandr Selivanov <alexgearbox@yandex.ru>
 * @author Nikita <obraztsov568@gmail.com>
 * @author Анатолий <anatol_m@mail.ru>
 * @author Yuriy Skalko <yuriy.skalko@gmail.com>
 * @author Alexander Kh. <001.arx@gmail.com>
 * @author Vyacheslav Strenadko <vyacheslav.strenadko@gmail.com>
 * @author Wolterhon <hotmottot.1@gmail.com>
 * @author Zhassulan <zyesmukanov@gmail.com>
 * @author Yuri Pimenov <up@ftpsearch.lv>
 * @author Igor Tarasov <tigr@mail15.com>
 * @author Denis Simakov <akinoame1@gmail.com>
 * @author Kaens Bard <kaens@mail.ru>
 * @author Andrew Pleshakov <beotiger@mail.ru>
 * @author Змей Этерийский <evil_snake@eternion.ru>
 * @author Hikaru Nakajima <jisatsu@mail.ru>
 * @author Alexei Tereschenko <alexeitlex@yahoo.com>
 * @author Irina Ponomareva <irinaponomareva@webperfectionist.com>
 * @author Alexander Sorkin <kibizoid@gmail.com>
 * @author Kirill Krasnov <krasnovforum@gmail.com>
 * @author Vlad Tsybenko <vlad.development@gmail.com>
 * @author Aleksey Osadchiy <rfc@nm.ru>
 * @author Ladyko Andrey <fylh@succexy.spb.ru>
 * @author Eugene <windy.wanderer@gmail.com>
 * @author Johnny Utah <pcpa@cyberpunk.su>
 * @author Ivan I. Udovichenko (sendtome@mymailbox.pp.ua)
 * @author Pavel <ivanovtsk@mail.ru>
 * @author Artur <ncuxxx@gmail.com>
 * @author Erli Moen <evseev.jr@gmail.com>
 * @author Владимир <id37736@yandex.ru>
 * @author Igor Degraf <igordegraf@gmail.com>
 * @author Type-kun <workwork-1@yandex.ru>
 * @author Vitaly Filatenko <kot@hacktest.net>
 * @author Alex P <alexander@lanos.co.uk>
 * @author Nolf <m.kopachovets@gmail.com>
 * @author Takumo <9206984@mail.ru>
 * @author RainbowSpike <1@2.ru>
 * @author dimsharav <dimsharav@gmail.com>
 * @author Radimir <radimir.shevchenko@gmail.com>
 * @author alexey <xeenych@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '«';
$lang['doublequoteclosing']    = '»';
$lang['singlequoteopening']    = '„';
$lang['singlequoteclosing']    = '“';
$lang['apostrophe']            = '“';
$lang['btn_edit']              = 'Править страницу';
$lang['btn_source']            = 'Показать исходный текст';
$lang['btn_show']              = 'Показать страницу';
$lang['btn_create']            = 'Создать страницу';
$lang['btn_search']            = 'Найти';
$lang['btn_save']              = 'Сохранить';
$lang['btn_preview']           = 'Просмотр';
$lang['btn_top']               = 'Наверх';
$lang['btn_newer']             = '<< более новые';
$lang['btn_older']             = 'более старые >>';
$lang['btn_revs']              = 'История страницы';
$lang['btn_recent']            = 'Недавние изменения';
$lang['btn_upload']            = 'Загрузить';
$lang['btn_cancel']            = 'Отменить';
$lang['btn_index']             = 'Все страницы';
$lang['btn_secedit']           = 'Править';
$lang['btn_login']             = 'Войти';
$lang['btn_logout']            = 'Выйти';
$lang['btn_admin']             = 'Управление';
$lang['btn_update']            = 'Обновить';
$lang['btn_delete']            = 'Удалить';
$lang['btn_back']              = 'Назад';
$lang['btn_backlink']          = 'Ссылки сюда';
$lang['btn_subscribe']         = 'Управление подписками';
$lang['btn_profile']           = 'Профиль';
$lang['btn_reset']             = 'Вернуть';
$lang['btn_resendpwd']         = 'Установить новый пароль';
$lang['btn_draft']             = 'Править черновик';
$lang['btn_recover']           = 'Восстановить черновик';
$lang['btn_draftdel']          = 'Удалить черновик';
$lang['btn_revert']            = 'Восстановить';
$lang['btn_register']          = 'Зарегистрироваться';
$lang['btn_apply']             = 'Применить';
$lang['btn_media']             = 'Управление медиафайлами';
$lang['btn_deleteuser']        = 'Удалить мой аккаунт';
$lang['btn_img_backto']        = 'Вернуться к %s';
$lang['btn_mediaManager']      = 'Просмотр в «управлении медиафайлами»';
$lang['loggedinas']            = 'Зашли как';
$lang['user']                  = 'Логин';
$lang['pass']                  = 'Пароль';
$lang['newpass']               = 'Новый пароль';
$lang['oldpass']               = 'Введите текущий пароль';
$lang['passchk']               = 'повторите';
$lang['remember']              = 'Запомнить меня';
$lang['fullname']              = 'Полное имя';
$lang['email']                 = 'Эл. адрес';
$lang['profile']               = 'Профиль пользователя';
$lang['badlogin']              = 'Извините, неверное имя пользователя или пароль.';
$lang['badpassconfirm']        = 'Простите, пароль неверный';
$lang['minoredit']             = 'Незначительные изменения';
$lang['draftdate']             = 'Черновик сохранён';
$lang['nosecedit']             = 'За это время страница была изменена и информация о секции устарела. Загружена полная версия страницы.';
$lang['searchcreatepage']      = 'Если вы не нашли то, что искали, то можете создать или изменить страницу %s, названную соответственно вашему запросу.';
$lang['search_fullresults']    = 'Результаты полнотекстового поиска';
$lang['js']['search_toggle_tools'] = 'Настройка поиска';
$lang['js']['willexpire']      = 'Ваша блокировка этой страницы на редактирование истекает в течение минуты.\nИспользуйте кнопку «Просмотр» для сброса таймера блокировки, чтобы предотвратить конфликты.';
$lang['js']['notsavedyet']     = 'Несохранённые изменения будут потеряны. Вы действительно хотите продолжить?';
$lang['js']['searchmedia']     = 'Поиск файлов';
$lang['js']['keepopen']        = 'Не закрывать окно после выбора';
$lang['js']['hidedetails']     = 'Скрыть детали';
$lang['js']['mediatitle']      = 'Настройка ссылки';
$lang['js']['mediadisplay']    = 'Тип ссылки';
$lang['js']['mediaalign']      = 'Выравнивание';
$lang['js']['mediasize']       = 'Размер';
$lang['js']['mediatarget']     = 'Целевая ссылка';
$lang['js']['mediaclose']      = 'Закрыть';
$lang['js']['mediainsert']     = 'Вставить';
$lang['js']['mediadisplayimg'] = 'Показывать изображение';
$lang['js']['mediadisplaylnk'] = 'Показывать только ссылку';
$lang['js']['mediasmall']      = 'Малая версия';
$lang['js']['mediamedium']     = 'Средняя версия';
$lang['js']['medialarge']      = 'Крупная версия';
$lang['js']['mediaoriginal']   = 'Исходная версия';
$lang['js']['medialnk']        = 'Ссылка на подробности';
$lang['js']['mediadirect']     = 'Прямая ссылка на оригинал';
$lang['js']['medianolnk']      = 'Без ссылки';
$lang['js']['medianolink']     = 'Не давать ссылку на изображение';
$lang['js']['medialeft']       = 'Выровнять изображение по левому краю';
$lang['js']['mediaright']      = 'Выровнять изображение по правому краю';
$lang['js']['mediacenter']     = 'Выровнять изображение по центру';
$lang['js']['medianoalign']    = 'Не выравнивать';
$lang['js']['nosmblinks']      = 'Ссылка на сетевые каталоги Windows работает только из MS Internet Explorer, но вы можете скопировать ссылку.';
$lang['js']['linkwiz']         = 'Мастер ссылок';
$lang['js']['linkto']          = 'Ссылка на:';
$lang['js']['del_confirm']     = 'Вы на самом деле желаете удалить выбранное?';
$lang['js']['restore_confirm'] = 'Действительно восстановить эту версию?';
$lang['js']['media_diff']      = 'Просмотр отличий:';
$lang['js']['media_diff_both'] = 'рядом';
$lang['js']['media_diff_opacity'] = 'наложением';
$lang['js']['media_diff_portions'] = 'частями';
$lang['js']['media_select']    = 'Выбрать файлы…';
$lang['js']['media_upload_btn'] = 'Загрузить';
$lang['js']['media_done_btn']  = 'Готово';
$lang['js']['media_drop']      = 'Переместите файлы сюда для загрузки';
$lang['js']['media_cancel']    = 'убрать';
$lang['js']['media_overwrt']   = 'Перезаписать существующие файлы';
$lang['search_exact_match']    = 'Точное совпадение';
$lang['search_starts_with']    = 'Начинается на';
$lang['search_ends_with']      = 'Заканчивается';
$lang['search_contains']       = 'Содержит';
$lang['search_custom_match']   = 'Задано пользователем';
$lang['search_any_ns']         = 'Все простр. имён';
$lang['search_any_time']       = 'Любое время';
$lang['search_past_7_days']    = 'Прошлая неделя';
$lang['search_past_month']     = 'Прошлый месяц';
$lang['search_past_year']      = 'Прошлый год';
$lang['search_sort_by_hits']   = 'Сорт. по популярности';
$lang['search_sort_by_mtime']  = 'Сорт. по последнему изменению';
$lang['regmissing']            = 'Извините, вам следует заполнить все поля.';
$lang['reguexists']            = 'Извините, пользователь с таким логином уже существует.';
$lang['regsuccess']            = 'Пользователь создан; пароль выслан на адрес электронной почты.';
$lang['regsuccess2']           = 'Пользователь создан.';
$lang['regfail']               = 'Пользователь не может быть создан.';
$lang['regmailfail']           = 'Похоже, есть проблема с отправкой пароля по почте. Пожалуйста, сообщите об этом администратору!';
$lang['regbadmail']            = 'Данный вами адрес электронной почты выглядит неправильным. Если вы считаете это ошибкой, сообщите администратору.';
$lang['regbadpass']            = 'Два введённых пароля не совпадают. Пожалуйста, попробуйте ещё раз.';
$lang['regpwmail']             = 'Ваш пароль для системы «Докувики»';
$lang['reghere']               = 'У вас ещё нет аккаунта? Зарегистрируйтесь';
$lang['profna']                = 'Данная вики не поддерживает изменение профиля';
$lang['profnochange']          = 'Изменений не было внесено, профиль не обновлён.';
$lang['profnoempty']           = 'Логин и адрес электронной почты не могут быть пустыми.';
$lang['profchanged']           = 'Профиль пользователя успешно обновлён.';
$lang['profnodelete']          = 'Данная вики не поддерживает удаление пользователей.';
$lang['profdeleteuser']        = 'Удалить аккаунт';
$lang['profdeleted']           = 'Ваш аккаунт был удалён из этой вики';
$lang['profconfdelete']        = 'Я хочу удалить свой аккаунт из этой вики.<br />Это действие необратимо.';
$lang['profconfdeletemissing'] = 'Флажок подтверждения не установлен';
$lang['proffail']              = 'Профиль пользователя не обновлён.';
$lang['pwdforget']             = 'Забыли пароль? Получите новый';
$lang['resendna']              = 'Вики не поддерживает повторную отправку пароля.';
$lang['resendpwd']             = 'Установить новый пароль для';
$lang['resendpwdmissing']      = 'Вы должны заполнить все поля формы.';
$lang['resendpwdnouser']       = 'Пользователь с таким логином не обнаружен в нашей базе данных.';
$lang['resendpwdbadauth']      = 'Извините, неверный код авторизации. Убедитесь, что вы полностью скопировали ссылку.';
$lang['resendpwdconfirm']      = 'Ссылка для подтверждения пароля была выслана по электронной почте.';
$lang['resendpwdsuccess']      = 'Ваш новый пароль был выслан по электронной почте.';
$lang['license']               = 'Если не указано иное, содержимое этой вики предоставляется на условиях следующей лицензии:';
$lang['licenseok']             = 'Примечание: редактируя эту страницу, вы соглашаетесь на использование своего вклада на условиях следующей лицензии:';
$lang['searchmedia']           = 'Поиск по имени файла:';
$lang['searchmedia_in']        = 'Поиск в %s';
$lang['txt_upload']            = 'Выберите файл для загрузки:';
$lang['txt_filename']          = 'Введите имя файла в вики (необязательно):';
$lang['txt_overwrt']           = 'Перезаписать существующий файл';
$lang['maxuploadsize']         = 'Макс. размер загружаемого файла %s.';
$lang['allowedmime']           = 'Список разрешённых расширений файлов';
$lang['lockedby']              = 'В данный момент заблокировано пользователем';
$lang['lockexpire']            = 'Блокировка истекает в';
$lang['rssfailed']             = 'Произошла ошибка при получении новостной ленты: ';
$lang['nothingfound']          = 'Ничего не найдено.';
$lang['mediaselect']           = 'Медиафайлы';
$lang['uploadsucc']            = 'Загрузка произведена успешно';
$lang['uploadfail']            = 'Загрузка не удалась. Возможно, проблемы с правами доступа?';
$lang['uploadwrong']           = 'В загрузке отказано. Файлы с таким расширением запрещены!';
$lang['uploadexist']           = 'Файл с таким именем существует. Загрузка не произведена.';
$lang['uploadbadcontent']      = 'Содержание файла не соответствует расширению %s.';
$lang['uploadspam']            = 'Загрузка заблокирована спам-фильтром.';
$lang['uploadxss']             = 'Загрузка заблокирована по соображениям безопасности.';
$lang['uploadsize']            = 'Загружаемый файл был слишком большим. (Макс. %s).';
$lang['deletesucc']            = 'Файл "%s" был удалён.';
$lang['deletefail']            = 'Невозможно удалить файл "%s" — проверьте права доступа к нему.';
$lang['mediainuse']            = 'Файл "%s" не был удалён — он всё ещё используется.';
$lang['namespaces']            = 'Пространства имён';
$lang['mediafiles']            = 'Доступные файлы';
$lang['accessdenied']          = 'Вы не можете просмотреть эту страницу.';
$lang['mediausage']            = 'Для ссылки на этот файл используйте следующий синтаксис:';
$lang['mediaview']             = 'Посмотреть исходный файл';
$lang['mediaroot']             = 'корень';
$lang['mediaupload']           = 'Загрузка файла в текущее пространство имён. Для создания подпространства имён добавьте его название перед именем файла через двоеточие. Поддерживается drag-and-drop (перетащить-и-оставить).';
$lang['mediaextchange']        = 'Расширение изменилось с .%s на .%s!';
$lang['reference']             = 'Ссылки для';
$lang['ref_inuse']             = 'Этот файл не может быть удалён, так как он используется на следующих страницах:';
$lang['ref_hidden']            = 'Некоторые ссылки находятся на страницах, на чтение которых у вас нет прав доступа';
$lang['hits']                  = 'совпад.';
$lang['quickhits']             = 'Подходящие страницы';
$lang['toc']                   = 'Содержание';
$lang['current']               = 'текущий';
$lang['yours']                 = 'Ваша версия';
$lang['diff']                  = 'Показать отличия от текущей версии';
$lang['diff2']                 = 'Показать различия между выбранными версиями';
$lang['difflink']              = 'Ссылка на это сравнение';
$lang['diff_type']             = 'Посмотреть различия';
$lang['diff_inline']           = 'внутри текста';
$lang['diff_side']             = 'двумя колонками';
$lang['diffprevrev']           = 'Предыдущая версия';
$lang['diffnextrev']           = 'Следующая версия';
$lang['difflastrev']           = 'Последняя версия';
$lang['diffbothprevrev']       = 'Предыдущая версия справа и слева';
$lang['diffbothnextrev']       = 'Следующая версия справа и слева';
$lang['line']                  = 'Строка';
$lang['breadcrumb']            = 'Вы посетили:';
$lang['youarehere']            = 'Вы находитесь здесь:';
$lang['lastmod']               = 'Последнее изменение:';
$lang['by']                    = ' —';
$lang['deleted']               = 'удалено';
$lang['created']               = 'создано';
$lang['restored']              = 'старая версия восстановлена (%s)';
$lang['external_edit']         = 'внешнее изменение';
$lang['summary']               = 'Сводка изменений';
$lang['unknowndate']           = 'Дата неизвестна';
$lang['noflash']               = 'Для просмотра этого содержимого требуется <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a>.';
$lang['download']              = 'Скачать фрагмент кода';
$lang['tools']                 = 'Инструменты';
$lang['user_tools']            = 'Инструменты пользователя';
$lang['site_tools']            = 'Инструменты сайта';
$lang['page_tools']            = 'Инструменты страницы';
$lang['skip_to_content']       = 'Перейти к содержанию';
$lang['sidebar']               = 'Боковая панель';
$lang['mail_newpage']          = 'страница добавлена:';
$lang['mail_changed']          = 'страница изменена:';
$lang['mail_subscribe_list']   = 'изменились страницы в пространстве имён:';
$lang['mail_new_user']         = 'новый пользователь:';
$lang['mail_upload']           = 'файл загружен:';
$lang['changes_type']          = 'Посмотреть изменения';
$lang['pages_changes']         = 'страниц';
$lang['media_changes']         = 'медиафайлов';
$lang['both_changes']          = 'и страниц, и медиафайлов';
$lang['qb_bold']               = 'Полужирный';
$lang['qb_italic']             = 'Курсив';
$lang['qb_underl']             = 'Подчёркнутый';
$lang['qb_code']               = 'Моноширинный';
$lang['qb_strike']             = 'Зачёркнутый';
$lang['qb_h1']                 = 'Заголовок 1-го уровня';
$lang['qb_h2']                 = 'Заголовок 2-го уровня';
$lang['qb_h3']                 = 'Заголовок 3-го уровня';
$lang['qb_h4']                 = 'Заголовок 4-го уровня';
$lang['qb_h5']                 = 'Заголовок 5-го уровня';
$lang['qb_h']                  = 'Заголовок';
$lang['qb_hs']                 = 'Выбор заголовка';
$lang['qb_hplus']              = 'Заголовок большего уровня';
$lang['qb_hminus']             = 'Заголовок меньшего уровня (подзаголовок)';
$lang['qb_hequal']             = 'Заголовок текущего уровня';
$lang['qb_link']               = 'Внутренняя ссылка';
$lang['qb_extlink']            = 'Внешняя ссылка';
$lang['qb_hr']                 = 'Горизонтальная линия';
$lang['qb_ol']                 = 'Элемент нумерованного списка';
$lang['qb_ul']                 = 'Элемент ненумерованного списка';
$lang['qb_media']              = 'Добавить изображения или другие файлы (откроется в новом окне)';
$lang['qb_sig']                = 'Вставить подпись';
$lang['qb_smileys']            = 'Смайлики';
$lang['qb_chars']              = 'Специальные символы';
$lang['upperns']               = 'Перейти в родительское пространство имён';
$lang['metaedit']              = 'Править метаданные';
$lang['metasaveerr']           = 'Ошибка записи метаданных';
$lang['metasaveok']            = 'Метаданные сохранены';
$lang['img_title']             = 'Название:';
$lang['img_caption']           = 'Подпись:';
$lang['img_date']              = 'Дата:';
$lang['img_fname']             = 'Имя файла:';
$lang['img_fsize']             = 'Размер:';
$lang['img_artist']            = 'Фотограф:';
$lang['img_copyr']             = 'Авторские права:';
$lang['img_format']            = 'Формат:';
$lang['img_camera']            = 'Модель камеры:';
$lang['img_keywords']          = 'Ключевые слова:';
$lang['img_width']             = 'Ширина:';
$lang['img_height']            = 'Высота:';
$lang['subscr_subscribe_success'] = 'Добавлен %s в подписку на %s';
$lang['subscr_subscribe_error'] = 'Невозможно добавить %s в подписку на %s';
$lang['subscr_subscribe_noaddress'] = 'Нет адреса электронной почты, сопоставленного с вашей учётной записью. Вы не можете подписаться на рассылку';
$lang['subscr_unsubscribe_success'] = 'Удалён %s из подписки на %s';
$lang['subscr_unsubscribe_error'] = 'Ошибка удаления %s из подписки на %s';
$lang['subscr_already_subscribed'] = '%s уже подписан на %s';
$lang['subscr_not_subscribed'] = '%s не подписан на %s';
$lang['subscr_m_not_subscribed'] = 'Вы не подписаны на текущую страницу или пространство имён.';
$lang['subscr_m_new_header']   = 'Добавить подписку';
$lang['subscr_m_current_header'] = 'Текущие подписки';
$lang['subscr_m_unsubscribe']  = 'Отменить подписку';
$lang['subscr_m_subscribe']    = 'Подписаться';
$lang['subscr_m_receive']      = 'Получить';
$lang['subscr_style_every']    = 'уведомлять о каждом изменении';
$lang['subscr_style_digest']   = 'информационное электронное письмо со списком изменений для каждой страницы (каждые %.2f дн.)';
$lang['subscr_style_list']     = 'список изменённых страниц со времени последнего отправленного электронного письма (каждые %.2f дн.)';
$lang['authtempfail']          = 'Аутентификация пользователей временно недоступна. Если проблема продолжается какое-то время, пожалуйста, сообщите об этом администратору вики.';
$lang['i_chooselang']          = 'Выберите свой язык / Choose your language';
$lang['i_installer']           = 'Установка «Докувики»';
$lang['i_wikiname']            = 'Название вики';
$lang['i_enableacl']           = 'Разрешить ограничение прав доступа (рекомендуется)';
$lang['i_superuser']           = 'Суперпользователь';
$lang['i_problems']            = 'Программа установки столкнулась с проблемами, перечисленными ниже. Чтобы продолжить, вам необходимо их устранить. ';
$lang['i_modified']            = 'Из соображений безопасности эта программа запускается только на новой, неизменённой установке «Докувики».
                                  Вам нужно либо заново распаковать скачанный пакет установки, либо обратиться к полной
                                  <a href="https://www.dokuwiki.org/install">инструкции по установке «Докувики»</a>';
$lang['i_funcna']              = 'Функция PHP <code>%s</code> недоступна. Может быть, она по какой-то причине заблокирована вашим хостером?';
$lang['i_disabled']            = 'Отключено вашим провайдером.';
$lang['i_funcnmail']           = '<b>Примечание:</ b> PHP-функция mail недоступна. %s Если она по прежнему недоступна, вы можете установить <a href="https://www.dokuwiki.org/plugin:smtp">плагин SMTP</a>.';
$lang['i_phpver']              = 'Ваша версия PHP (<code>%s</code>) ниже требуемой (<code>%s</code>). Вам необходимо обновить установленную версию PHP.';
$lang['i_mbfuncoverload']      = 'Для запуска «Докувики» необходимо отключить параметр mbstring.func_overload в php.ini';
$lang['i_urandom']             = '«Докувики» не может создавать криптографически безопасные номера для файлов cookie. Возможно, вы захотите проверить настройки open_basedir в php.ini для правильного доступа <code>/dev/urandom</ code>.';
$lang['i_permfail']            = '<code>%s</code> недоступна для записи «Докувики». Вам необходимо исправить системные права доступа для этой директории!';
$lang['i_confexists']          = '<code>%s</code> уже существует';
$lang['i_writeerr']            = 'Не удалось создать <code>%s</code>. Вам необходимо проверить системные права доступа к файлу и директориям, и создать файл вручную.';
$lang['i_badhash']             = 'dokuwiki.php не распознан или изменён (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> — недопустимое или пустое значение';
$lang['i_success']             = 'Настройка прошла успешно. Теперь вы можете удалить файл install.php. Переходите к
                                 <a href="doku.php?id=wiki:welcome">своей новой «Докувики»</a>.';
$lang['i_failure']             = 'При записи в файлы конфигурации были обнаружены ошибки. Возможно, вам придётся исправить их вручную, прежде чем вы сможете использовать <a href="doku.php?id=wiki:welcome">свою новую «Докувики»</a>.';
$lang['i_policy']              = 'Исходная политика прав доступа';
$lang['i_pol0']                = 'Открытая вики (чтение, запись, загрузка файлов для всех)';
$lang['i_pol1']                = 'Общедоступная вики (чтение для всех, запись и загрузка файлов для зарегистрированных пользователей)';
$lang['i_pol2']                = 'Закрытая вики (чтение, запись и загрузка файлов только для зарегистрированных пользователей)';
$lang['i_allowreg']            = 'Разрешить пользователям самостоятельно регистрироваться';
$lang['i_retry']               = 'Повторить попытку';
$lang['i_license']             = 'Пожалуйста, выберите тип лицензии для своей вики';
$lang['i_license_none']        = 'Не отображать информацию о лицензии';
$lang['i_pop_field']           = 'Пожалуйста, помогите нам улучшить «Докувики»:';
$lang['i_pop_label']           = 'Отправлять раз в месяц анонимную пользовательскую информацию разработчикам «Докувики»';
$lang['recent_global']         = 'Вы просматриваете изменения в пространстве имён <b>%s</b>. Вы можете также <a href="%s">просмотреть недавние изменения во всей вики</a>.';
$lang['years']                 = '%d лет назад';
$lang['months']                = '%d мес. назад';
$lang['weeks']                 = '%d нед. назад';
$lang['days']                  = '%d дн. назад';
$lang['hours']                 = '%d ч. назад';
$lang['minutes']               = '%d мин. назад';
$lang['seconds']               = '%d сек. назад';
$lang['wordblock']             = 'Ваши изменения не сохранены, поскольку они содержат блокируемые слова (спам).';
$lang['media_uploadtab']       = 'Загрузка';
$lang['media_searchtab']       = 'Найти';
$lang['media_file']            = 'Файл';
$lang['media_viewtab']         = 'Просмотр';
$lang['media_edittab']         = 'Правка';
$lang['media_historytab']      = 'История';
$lang['media_list_thumbs']     = 'Миниатюры';
$lang['media_list_rows']       = 'Строки';
$lang['media_sort_name']       = 'Сортировка по имени';
$lang['media_sort_date']       = 'Сортировка по дате';
$lang['media_namespaces']      = 'Выберите пространство имён';
$lang['media_files']           = 'Файлы в %s';
$lang['media_upload']          = 'Загрузка в пространство имён %s';
$lang['media_search']          = 'Поиск в пространстве имён %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s в %s
';
$lang['media_edit']            = 'Правка %s';
$lang['media_history']         = 'История %s';
$lang['media_meta_edited']     = 'метаданные изменены';
$lang['media_perm_read']       = 'Извините, у вас недостаточно прав для чтения файлов.';
$lang['media_perm_upload']     = 'Извините, у вас недостаточно прав для загрузки файлов.';
$lang['media_update']          = 'Загрузить новую версию';
$lang['media_restore']         = 'Восстановить эту версию';
$lang['media_acl_warning']     = 'Этот список может быть неполным из-за ограничений списков контроля доступа (ACL) и скрытых страниц.';
$lang['email_fail']            = 'PHP mail() отсутствует или отключен. Следующее письмо не было отправлено: ';
$lang['currentns']             = 'Текущее пространство имён';
$lang['searchresult']          = 'Результаты поиска';
$lang['plainhtml']             = 'Простой HTML';
$lang['wikimarkup']            = 'вики-разметка';
$lang['page_nonexist_rev']     = 'Эта страница ещё не существовала %s. Она была создана <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Невозможно обработать параметр "%s".';
$lang['email_signature_text']  = 'Это письмо создано «Докувики» с сайта
@DOKUWIKIURL@';
